@@ -3,14 +3,7 @@ import time
 from notecoin.huobi.connection import (RestApiSyncClient, SubscribeClient,
                                        WebSocketReqClient)
 from notecoin.huobi.constant.system import HttpMethod
-from notecoin.huobi.model.market import (Candlestick, CandlestickEvent,
-                                         CandlestickReq, MarketDetail,
-                                         MarketDetailEvent, MarketDetailReq,
-                                         MbpFullEvent, MbpIncreaseEvent,
-                                         MbpReq, PriceDepth, PriceDepthBbo,
-                                         PriceDepthBboEvent, PriceDepthEvent,
-                                         PriceDepthReq, Trade, TradeDetail,
-                                         TradeDetailEvent, TradeDetailReq)
+from notecoin.huobi.model.market import Trade
 from notecoin.huobi.utils.channels import (kline_channel,
                                            market_detail_channel,
                                            mbp_full_channel,
@@ -22,8 +15,7 @@ from notecoin.huobi.utils.channels import (kline_channel,
 from notecoin.huobi.utils.channels_request import (
     request_kline_channel, request_market_detail_channel,
     request_price_depth_channel, request_trade_detail_channel)
-from notecoin.huobi.utils.json_parser import (default_parse,
-                                              default_parse_list_dict)
+from notecoin.huobi.utils.json_parser import default_parse_list_dict
 
 
 class MarketService(RestApiSyncClient):
@@ -90,10 +82,7 @@ class MarketServiceSocket(WebSocketReqClient):
                 connection.send(request_kline_channel(symbol, interval, from_ts_second, end_ts_second))
                 time.sleep(0.01)
 
-        def parse(dict_data):
-            return default_parse(dict_data, CandlestickReq, Candlestick)
-
-        self.execute_subscribe_v1(subscription, parse, callback, error_handler)
+        self.execute_subscribe_v1(subscription, callback, error_handler)
 
     def req_market_detail_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
@@ -103,10 +92,7 @@ class MarketServiceSocket(WebSocketReqClient):
                 connection.send(request_market_detail_channel(symbol))
                 time.sleep(0.01)
 
-        def parse(dict_data):
-            return default_parse(dict_data, MarketDetailReq, MarketDetail)
-
-        self.execute_subscribe_v1(subscription, parse, callback, error_handler)
+        self.execute_subscribe_v1(subscription, callback, error_handler)
 
     def req_mbp_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
@@ -117,11 +103,7 @@ class MarketServiceSocket(WebSocketReqClient):
                 connection.send(request_mbp_channel(symbol, level))
                 time.sleep(0.01)
 
-        def parse(dict_data):
-            return MbpReq.json_parse(dict_data)
-
         self.execute_subscribe_mbp(subscription,
-                                   parse,
                                    callback,
                                    error_handler)
 
@@ -134,19 +116,7 @@ class MarketServiceSocket(WebSocketReqClient):
                 connection.send(request_price_depth_channel(symbol, step))
                 time.sleep(0.01)
 
-        def parse(dict_data):
-            price_depth_event = PriceDepthReq()
-            price_depth_event.id = dict_data.get("id")
-            price_depth_event.rep = dict_data.get("rep")
-            data = dict_data.get("data", {})
-            price_depth_obj = PriceDepth.json_parse(data)
-            price_depth_event.data = price_depth_obj
-            return price_depth_event
-
-        self.execute_subscribe_v1(subscription,
-                                  parse,
-                                  callback,
-                                  error_handler)
+        self.execute_subscribe_v1(subscription, callback, error_handler)
 
     def req_trade_detail_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
@@ -156,13 +126,7 @@ class MarketServiceSocket(WebSocketReqClient):
                 connection.send(request_trade_detail_channel(symbol))
                 time.sleep(0.01)
 
-        def parse(dict_data):
-            return default_parse(dict_data, TradeDetailReq, TradeDetail)
-
-        self.execute_subscribe_v1(subscription,
-                                  parse,
-                                  callback,
-                                  error_handler)
+        self.execute_subscribe_v1(subscription, callback, error_handler)
 
 
 class MarketServiceSub(SubscribeClient):
@@ -178,13 +142,7 @@ class MarketServiceSub(SubscribeClient):
                 connection.send(kline_channel(symbol, interval))
                 time.sleep(0.01)
 
-        def parse(dict_data):
-            return default_parse(dict_data, CandlestickEvent, Candlestick)
-
-        self.execute_subscribe_v1(subscription,
-                                  parse,
-                                  callback,
-                                  error_handler)
+        self.execute_subscribe_v1(subscription, callback, error_handler)
 
     def sub_market_detail_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
@@ -194,13 +152,7 @@ class MarketServiceSub(SubscribeClient):
                 connection.send(market_detail_channel(symbol))
                 time.sleep(0.01)
 
-        def parse(dict_data):
-            return default_parse(dict_data, MarketDetailEvent, MarketDetail)
-
-        self.execute_subscribe_v1(subscription,
-                                  parse,
-                                  callback,
-                                  error_handler)
+        self.execute_subscribe_v1(subscription, callback, error_handler)
 
     def sub_mbp_full_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
@@ -211,13 +163,7 @@ class MarketServiceSub(SubscribeClient):
                 connection.send(mbp_full_channel(symbol, level))
                 time.sleep(0.01)
 
-        def parse(dict_data):
-            return MbpFullEvent.json_parse(dict_data)
-
-        self.execute_subscribe_v1(subscription,
-                                  parse,
-                                  callback,
-                                  error_handler)
+        self.execute_subscribe_v1(subscription, callback, error_handler)
 
     def sub_mbp_increase_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
@@ -228,13 +174,7 @@ class MarketServiceSub(SubscribeClient):
                 connection.send(mbp_increase_channel(symbol, level))
                 time.sleep(0.01)
 
-        def parse(dict_data):
-            return MbpIncreaseEvent.json_parse(dict_data)
-
-        self.execute_subscribe_mbp(subscription,
-                                   parse,
-                                   callback,
-                                   error_handler)
+        self.execute_subscribe_mbp(subscription, callback, error_handler)
 
     def sub_price_depth_bbo_service(self, callback, error_handler, params):
         symbol_list = params["symbol_list"]
@@ -244,11 +184,7 @@ class MarketServiceSub(SubscribeClient):
                 connection.send(price_depth_bbo_channel(symbol))
                 time.sleep(0.01)
 
-        def parse(dict_data):
-            return default_parse(dict_data, PriceDepthBboEvent, PriceDepthBbo)
-
         self.execute_subscribe_v1(subscription,
-                                  parse,
                                   callback,
                                   error_handler)
 
@@ -261,15 +197,7 @@ class MarketServiceSub(SubscribeClient):
                 connection.send(price_depth_channel(symbol, step))
                 time.sleep(0.01)
 
-        def parse(dict_data):
-            price_depth_event_obj = PriceDepthEvent()
-            price_depth_event_obj.ch = dict_data.get("ch", "")
-            tick = dict_data.get("tick", "")
-            price_depth_event_obj.tick = PriceDepth.json_parse(tick)
-            return price_depth_event_obj
-
         self.execute_subscribe_v1(subscription,
-                                  parse,
                                   callback,
                                   error_handler)
 
@@ -281,13 +209,4 @@ class MarketServiceSub(SubscribeClient):
                 connection.send(trade_detail_channel(symbol))
                 time.sleep(0.01)
 
-        def parse(dict_data):
-            tick = dict_data.get("tick", {})
-            trade_detail_event = default_parse(tick, TradeDetailEvent, TradeDetail)
-            trade_detail_event.ch = dict_data.get("ch", "")
-            return trade_detail_event
-
-        self.execute_subscribe_v1(subscription,
-                                  parse,
-                                  callback,
-                                  error_handler)
+        self.execute_subscribe_v1(subscription, callback, error_handler)
